<?php
/**
 * @file
 * List of all error messages.
 */

/**
 * List of all error messages for Datacash response.
 *
 * @param int $status
 *   Status.
 *
 * @return string
 *   Message of the code.
 *
 * @see https://testserver.datacash.com/software/returncodes.shtml#General
 */
function commerce_datacash_get_error_message($status) {
  $error_messages = array(
    2 => 'Socket write error',
    3 => 'Timeout',
    5 => 'Edit error',
    6 => 'Comms error',
    7 => 'Not authorised',
    9 => 'Currency error',
    10 => 'Authentication error',
    12 => 'Invalid authorisation code',
    13 => 'Type field missing',
    14 => 'Database server error',
    15 => 'Invalid type',
    19 => 'Cannot fulfill transaction',
    20 => 'Duplicate transaction reference',
    21 => 'Invalid card type',
    22 => 'Invalid reference',
    23 => 'Expiry date invalid',
    24 => 'Card has already expired',
    25 => 'Card number invalid',
    26 => 'Card number wrong length',
    27 => 'Issue number error',
    28 => 'Start date error',
    29 => 'Card is not valid yet',
    30 => 'Start date after expiry date',
    34 => 'Invalid amount',
    40 => 'Invalid cheque type',
    41 => 'Invalid cheque number',
    42 => 'Invalid sort code',
    44 => 'Invalid account number',
    51 => 'Reference in use',
    53 => 'No free TIDs available for this vTID',
    56 => 'Card used too recently',
    57 => 'Invalid velocity_check value',
    59 => 'This combination of currency, card type and environment is not supported by this vTID',
    60 => 'Invalid XML',
    61 => 'Configuration error',
    62 => 'Unsupported protocol',
    63 => 'Method not supported by acquirer',
    104 => 'APACS30: WRONG TID',
    105 => 'APACS30: MSG SEQ NUM ERR',
    106 => 'APACS30: WRONG AMOUNT',
    190 => 'No capture method specified',
    271 => 'Cannot query transactions of this kind',
    274 => 'Cannot locate transaction to query',
    280 => 'Unknown format of datacash reference',
    281 => 'Datacash reference fails Luhn check',
    282 => 'Mismatch between historic and current site_id',
    283 => 'Mismatch between historic and current modes',
    440 => 'Payment Gateway Busy',
    470 => 'Maestro txns for CNP not supported for clearinghouse',
    471 => '3-D Secure Required',
    472 => 'Invalid capturemethod',
    473 => 'Invalid transaction type',
    480 => 'Invalid value for merchantid',
    481 => 'Element merchantid required',
    482 => 'Invalid element merchantid',
    510 => 'GE Capital: Inappropriate GE Capital card number',
    1100 => 'No referenced transaction found',
    1101 => 'Only referred transactions can be authorised',
    1102 => 'Only pre or auth transaction can be authorised',
    1103 => 'Must supply updated authcode to authorise transaction',
    1104 => 'Transactions cannot be authorized after time limit expired',
    1105 => 'Fraud challenged transactions cannot be authorized',
    1106 => 'Historic reference already in use',
    12001 => 'vtidconfiguration',
    12002 => 'vtidconfiguration',
    70 => 'Validation errors relating to Direct Debit',
    71 => 'Invalid setup transaction',
    73 => 'Cannot confirm the presetup transaction',
    74 => 'Invalid drawdown transaction',
    75 => 'Mode mismatch',
    580 => 'Direct Debit: amount may not be supplied in DDI setup request',
    80 => 'Invalid LID data',
    81 => 'Missing mandatory field',
    82 => 'Invalid VAT rate',
    83 => 'Invalid Commodity Code',
    84 => 'Invalid transaction VAT amount',
    85 => 'Support for LID not enabled',
    86 => 'Non-purchasing card using for a LID transaction.',
    87 => 'Line total does not match items',
    90 => 'Invalid Value',
    91 => 'Field Missing',
    92 => 'CA Not Supported',
    93 => 'Invalid Card',
    94 => 'Invalid Date',
    95 => 'Invalid Cancellation',
    96 => 'Invalid Last Payment',
    97 => 'No CA Support',
    98 => 'Not supported for this bank',
    99 => 'Invalid Account Ref',
    100 => 'Merchant not subscribed for 3DSecure',
    101 => 'Missing 3DSecure elements',
    102 => 'Missing or invalid Secure attribute',
    103 => 'Invalid capturemethod for 3DSecure',
    107 => 'Incorrect use of 3DSecure elements',
    108 => 'Card scheme does not support 3D secure',
    120 => 'Not subscribed',
    121 => 'Duplicate reference',
    122 => 'Non-GBP amount specified.',
    123 => 'Non-UK Issued card used.',
    124 => 'Cardname is over 18 characters long.',
    125 => 'Direct Credit system error.',
    126 => 'Unknown payment details.',
    127 => 'Transaction limit has been exceeded.',
    128 => 'Direct Credit transaction has already been cancelled.',
    129 => 'Direct Credit has been submitted to BACS.',
    134 => 'Invalid format for Account Name',
    135 => 'Details Failed Bank Validation check',
    136 => 'Bank Details fail BACS check',
    137 => 'Unable to locate matching DDI transaction',
    130 => 'Invalid to use both policies',
    131 => 'Invalid ExtendedPolicy definition',
    132 => 'Expected 3 or 4 digit CV2 number',
    133 => 'Extended Policy not supported',
    140 => 'Merchant not subscribed to DD CA',
    141 => 'Non-GBP not supported for DD CA',
    142 => 'No matching DD setup',
    143 => 'Invalid last flagging',
    144 => 'DD Setup not active',
    145 => 'DD Setup is in accreditation mode',
    146 => 'DD Setup is in disabled mode',
    150 => '3DS Payer Verification Required',
    151 => '3DS Invalid Transaction type',
    152 => '3DS Manual Authorization not supported',
    153 => '3DS verify element missing',
    154 => '3DS Invalid verify value\'',
    155 => '3DS field missing',
    156 => '3DS Invalid Browser.device_category',
    157 => '3DS Merchant not enabled',
    158 => '3DS scheme not supported',
    159 => '3DS No VERes from DS',
    160 => '3DS Invalid VERes from DS',
    161 => '3DS call auth centre',
    162 => '3DS Card not Enrolled',
    163 => '3DS Merchant not enabled for scheme acquirer',
    164 => '3DS Acquirer not supported',
    165 => '3DS Merchant not enabled for acquirer',
    166 => '3DS purchase_datetime format invalid',
    167 => '3DS Invalid reference',
    168 => '3DS txn cannot be authorized',
    169 => '3DS Merchant in test-mode supplied non-magic card',
    170 => '3DS No DS URL for card scheme',
    171 => '3DS pares_message supplied for non-enrolled card',
    172 => '3DS pares_message missing for enrolled card',
    173 => '3DS Card not Enrolled in Cache',
    174 => '3DS Invalid pares signature',
    175 => '3DS No corresponding pareq found',
    176 => '3DS invalid pares',
    177 => '3DS invalid pareq',
    178 => '3DS pareq vs pares mismatch',
    179 => '3DS Payer failed Verification',
    180 => '3DS No Support for CA',
    181 => '3DS No corresponding referral',
    182 => '3DS Referral timelimit exceeded',
    183 => '3DS Verification Bypassed',
    184 => '3DS Expired Awaiting Authorization',
    185 => '3DS Expired Referral',
    186 => '3DS Invalid VEReq',
    187 => 'Unable to Verify',
    188 => 'Unable to Authenticate',
    189 => '3DS International Maestro card not enrolled',
    600 => 'Authentication can only be performed for enrolled cards',
    601 => 'No 3-D Secure enrollment found for reference supplied',
    602 => '3-D Secure enrollment check already validated for reference supplied',
    603 => 'No 3-D Secure authentication found for reference supplied',
    604 => 'Transaction already authorised for reference supplied',
    605 => 'threedsecure_authorization_request not permitted on transactions of this type.',
    606 => 'Invalid PARes',
    607 => 'MPI authentication has expired',
    608 => 'Invalid currency',
    609 => 'Currency must be supplied',
    610 => 'No mid found for currency or 3DS scheme not supported',
    611 => 'Unable to process authorisation',
    612 => 'Unable to process authorisation',
    613 => 'MPI System Configuration Error',
    640 => 'Merchant mandated 3-D Secure transaction, none attempted',
    641 => 'Merchant attempted 3-D Secure transaction override, but is not permitted',
    191 => 'Field not applicable to CA setup',
    192 => 'Failed to find corresponding CA account',
    193 => 'Missing CA environment attribute',
    194 => 'Invalid use of CA environment attribute',
    195 => 'Non-CA capturemethod required',
    199 => 'Invalid Refund',
    200 => 'Information Mismatch',
    201 => 'Missing Information',
    202 => 'VGIS parse error',
    203 => 'Support for VGIS not enabled',
    204 => 'Non-VGIS Card',
    205 => 'Invalid Totals',
    206 => 'Invalid Tax Amount',
    207 => 'Invalid Value',
    208 => 'VGIS message limit exceeded',
    209 => 'VGIS decompression failed',
    210 => 'Invalid environment for reversal',
    211 => 'CHP: Capturemethod method missing',
    212 => 'Use of Terminal element invalid',
    213 => 'Terminal\' element missing',
    214 => 'Terminal capabilities invalid',
    215 => 'Invalid Cash Back',
    217 => 'Cash back not allowed in this environment',
    218 => 'CV2AVS n/a in CHP environment',
    219 => 'CHP: ReD rich data set n/a',
    220 => 'Invalid transaction type',
    221 => 'Invalid card and capturemethod combination',
    222 => 'CHP: Authcode method attribute error',
    223 => 'CNP: Authcode method attribute error',
    224 => 'Hotcardfile not allowed in this environment',
    225 => 'LID n/a in CHP environment',
    226 => 'Invalid environment for track 2 data',
    227 => 'Invalid track 2 data',
    228 => 'Track 2 data missing',
    229 => 'ICC data n/a in this environment',
    230 => 'ICC data missing',
    231 => 'Cash back > amount',
    232 => 'Cash back n/a to card type',
    233 => 'Field reason_online_code not applicable to Card Holder Not Present',
    234 => 'CHP No support for CA',
    235 => 'Invalid ICC data',
    236 => 'CHP: Invalid receipt number',
    237 => 'CHP: Receipt number specified where invalid',
    238 => 'CHP: Authcode auth_datetime attribute error',
    239 => 'CHP: Transaction cannot be settled',
    240 => 'CP - Track 2 data not allowed',
    241 => 'Cash Advance - Max Cash amount exceeded',
    242 => 'Cash Advance not allowed for this card type',
    243 => 'Cash Advance not supported for this acquirer',
    244 => 'Cash Advance not allowed in this environment',
    245 => 'Cash Advance not supported in this currency',
    246 => 'Invalid Cash Advance data',
    247 => 'Missing currency parameter',
    1150 => 'Invalid TID specified in XML',
    250 => 'Prereg: Invalid reference',
    251 => 'Prereg: Merchant Not Subscribed',
    252 => 'Prereg: Invalid reference - vTIDgroup mismatch',
    255 => 'BatchInput: Not authorised',
    256 => 'BatchInput: Too many files',
    257 => 'BatchInput: Input file too big',
    258 => 'BatchInput: Input format not recognised',
    259 => 'BatchInput: The compressed and encoded batch data is corrupt',
    260 => 'BatchInput: Data file parse failure',
    261 => 'BatchInput: Malformed data file header',
    262 => 'BatchInput: Invalid transaction count',
    263 => 'BatchInput: Invalid total amount',
    264 => 'BatchInput: Batch file format violation',
    265 => 'BatchInput: Illegal batch data value',
    266 => 'BatchInput: Processing aborted - cannot have empty mandatory field',
    267 => 'BatchInput: Processing aborted - cannot use different vTIDs in XML batches',
    268 => 'BatchInput: Processing aborted - cannot use query txns via this interface',
    270 => 'Not authorised to perform query txns',
    272 => 'BatchInput: Unprocessed',
    273 => 'BatchInput: Processing',
    275 => 'BatchInput: Processing Failed',
    276 => 'BatchInput: No preprocessed transaction found',
    290 => 'Missing or corrupted Flight Leg number',
    291 => 'Support for Airlines transaction not enabled',
    292 => 'Duplicate passenger reference',
    293 => 'Airlines ticket prices do not reconcile with transaction amount',
    294 => 'Airlines: Data already supplied',
    295 => 'Airlines: pre/erp txn for this amex airlines fulfill contained no airlines data',
    296 => 'Airlines: No airlines data supplied for this transaction',
    297 => 'Airlines: Invalid extended data',
    298 => 'Airlines: Invalid refund',
    299 => 'Airlines: Invalid capturemethod',
    301 => 'Address Record not supported',
    310 => 'T3M: Not subscribed',
    311 => 'T3M: Cannot mix old and new schema formats',
    312 => 'T3M: Validation Error',
    313 => 'T3M Batching error',
    314 => 'T3M:PayPal Validation Error',
    315 => 'T3M:Fraud only Validation Error',
    316 => 'T3M:Fraud only Response Error',
    317 => 'T3M:Fraud only Communication Error',
    318 => 'T3M:Fraud only Response Error',
    319 => 'T3M:Fraud only Communication error',
    1126 => 'Transaction rejected by the RSG',
    1127 => 'Transaction marked for review',
    1128 => 'Referenced transaction cannot be accepted',
    1130 => 'Invalid RSG service specified',
    1131 => 'Transaction has expired and cannot be completed',
    1133 => 'The RSG service can only be used in the ecomm, cnp or cont_auth environments',
    1134 => 'Not subscribed to the RSG service',
    1135 => 'Referenced transaction not found',
    1136 => 'Fire and Forget Continuous Authority transactions not supported with the RSG service',
    1137 => 'Historic Continuous Authority transactions not supported with the RSG service',
    1138 => 'Other fraud screening services cannot be used in conjunction with the RSG service',
    1139 => 'Method unsupported for the RSG service',
    1140 => 'Transaction marked for review',
    320 => 'OTR: Merchant Reference invalid for acquirer',
    321 => 'OTR: Acquirer configuration missing',
    330 => 'Merchant not subscribed for Smart Voucher',
    331 => 'Missing Field',
    332 => 'Invalid capturemethod',
    333 => 'Invalid voucher number',
    334 => 'Invalid product code',
    335 => 'Invalid account number',
    336 => 'Invalid Smart Voucher value',
    337 => 'Purchase value >= Redeem value',
    338 => 'Service incompatible with SmartVoucher',
    339 => 'APACS30: wrong product code',
    340 => 'APACS30: wrong voucher value',
    345 => 'Merchant not subscribed for merchant ref cancellations',
    346 => 'Merchant ref is not unique',
    347 => 'Cannot cancel this txn type by merchant ref',
    348 => 'Do not supply a merchant reference and DataCash reference',
    350 => 'Age Verification: Connection Error',
    351 => 'Age Verification: No Response',
    352 => 'Age Verification: Invalid Response',
    353 => 'Age Verification: Error Response',
    354 => 'Age Verification: Not Subscribed',
    355 => 'Age Verification: Bad Configuration',
    356 => 'Age Verification: Missing Data',
    357 => 'Age Verification: Extra Data',
    358 => 'Age Verification: Invalid Data',
    359 => 'Age Verification: Incorrect Response',
    370 => 'Allocated reference already used',
    371 => 'Allocated reference had expired',
    372 => 'Not an allocated reference',
    373 => 'Cannot allocate references in this environment',
    374 => 'Cannot cancel unused reference',
    380 => 'Not subscribed for GCX DCC',
    381 => 'Invalid transaction details',
    382 => 'Invalid method',
    383 => 'Invalid scheme',
    384 => 'Invalid clearinghouse',
    385 => 'gcxreference field required for GCX transactions',
    390 => 'Merchant not subscribed to Click2Pay service',
    391 => 'Click2Pay: Connection Error',
    392 => 'Click2Pay: No response from Click2Pay server',
    393 => 'Click2Pay: Server returned invalid resposne',
    394 => 'Click2Pay: Server Error',
    395 => 'Click2Pay: Illegal Field',
    396 => 'Click2Pay: Unrecognised currency returned from Click2Pay server',
    421 => 'Omnipay - Network failure',
    422 => 'Datawire - Server Error',
    423 => 'Datawire - VXN Error',
    424 => 'Datawire - Invalid XML Response',
    425 => 'ISO 8583 - message corrupted',
    426 => 'Omnipay - merchant incorrectly configured',
    427 => 'Omnipay - Invalid input',
    428 => 'Omnipay - invalid card scheme',
    430 => 'Elavon - server error',
    431 => 'Elavon - invalid AVS details',
    450 => 'SEB: Euroline System Error',
    451 => 'SEB: Failure at bank',
    452 => 'SEB: Request/Response Mismatch',
    453 => 'SEB: Merchant incorrectly configured',
    454 => 'SEB: No connection configured for authorisations',
    455 => 'SEB: Unsupported message type',
    456 => 'No external tickets available for this service',
    457 => 'SEB: Insufficient Data to generate request message',
    460 => 'Not Subscribed',
    461 => 'Merchant incorrectly configured',
    462 => 'Invalid element',
    515 => 'Cannot reverse transaction',
    516 => 'Inappropriate card number',
    517 => 'Unexpected elements',
    518 => 'Invalid refund',
    519 => 'Invalid Environment',
    530 => 'VEoD: not configured for service',
    531 => 'VEoD: outside EoD window',
    532 => 'VEoD: already received an EoD',
    533 => 'VEoD: EoD misconfigured',
    534 => 'VEoD: EoD misconfigured',
    560 => 'PayPal: Not configured for service',
    561 => 'PayPal: Error returned in response',
    562 => 'PayPal: Warning returned in response',
    563 => 'PayPal: Already refunded',
    564 => 'PayPal: Partial refund amount exceeds available amount',
    565 => 'PayPal: Invalid reference',
    566 => 'PayPal: Mandatory field not supplied',
    567 => 'PayPal: Disallowed field supplied',
    568 => 'PayPal: Validation error',
    569 => 'PayPal: Communications Error',
    570 => 'PayPal: Incomplete transaction',
    571 => 'PayPal:Customer login pending',
    572 => 'Paypal:No Paypal response received - please query transaction status',
    573 => 'Paypal:Request not received by Paypal',
    574 => 'Paypal:Action in progress',
    575 => 'Paypal:Transaction failed',
    576 => 'Paypal:Unsuccessful status',
    577 => 'Paypal:Status update failed',
    578 => 'Paypal:Unable to determine transaction status at Paypal',
    630 => 'Unexpected elements',
    631 => 'Inappropriate card number',
    632 => 'Invalid environment',
    633 => 'Invalid refund',
    650 => 'Chase: Communications Error',
    651 => 'Chase: Request/Response Mismatch',
    652 => 'Chase: No external connection resource available',
    653 => 'Chase: Failure at bank',
    654 => 'Chase: Error in response',
    655 => 'Chase: Not configured for service',
    656 => 'Chase: Cannot reverse expired auth',
    657 => 'Chase: Unsupported Card Scheme',
    658 => 'Chase: Insufficient Data to generate request message',
    659 => 'Chase: Auth reversal cannot be processed on expired auth',
    660 => 'Chase: HTTP error in response',
    661 => 'Chase: Unknown Error',
    670 => 'Invalid NAB Merchant ID',
    671 => 'NAB suffered a database error whilst processing the transaction',
    672 => 'NAB encountered an error whilst processing the transaction',
    673 => 'NAB suffered a fatal unknown error',
    674 => 'NAB was unable to process the transaction',
    675 => 'NAB is undergoing system maintenance',
    676 => 'Invalid NAB password supplied',
    677 => 'NAB was unable to process the transaction',
    678 => 'NAB was unable to process the transaction',
    679 => 'NAB has disabled the merchant acccount used for this transaction.',
    680 => 'NAB was unable to process the transaction',
    681 => 'An unknown error has occurred processing the NAB transaction',
    682 => 'Merchant incorrectly configured for NAB',
    683 => 'NAB: Unable to establish connection to NAB',
    684 => 'NAB: HTTP error in response',
    685 => 'NAB: Communications Error',
    686 => 'Decryption/Encryption Error at NAB',
    687 => 'NAB Gateway Timeout, no response received from bank',
    688 => 'NAB complete transaction was for a greater amount than the preauth',
    689 => 'NAB payment amount is below the minimum specified by merchant',
    690 => 'NAB payment amount is above the maximum specified by merchant',
    691 => 'Transaction timed out while in the NAB queue',
    692 => 'Invalid response received from NAB',
    693 => 'Incorrect response received from NAB',
    694 => 'Pre-auth not found by NAB',
    695 => 'NAB pre-auth already completed',
    760 => 'Fuel Card Processing: Unexpected element in request',
    761 => 'Fuel Card Processing: Card provided is not a Fuel Card',
    762 => 'Fuel Card Processing: Invalid capturemethod (can only be keyed or swiped for Fuel Cards)',
    763 => 'Fuel Card Processing: Invalid fuel_settle txn',
    764 => 'Fuel Card Processing: Missing receipt_no element',
    810 => 'HPS: Inappropriate data supplied',
    811 => 'HPS: Missing data',
    812 => 'HPS: Invalid reference',
    813 => 'HPS: Communications error',
    814 => 'HPS: Invalid HPS response',
    815 => 'HPS: Invalid payment reference',
    816 => 'HPS: Merchant not configured',
    817 => 'HPS: Capture field data too long',
    818 => 'HPS: Dynamic Data Field too long',
    820 => 'HPS: Awaiting customer card details.',
    821 => 'HPS: At least one auth attempted. Awaiting payment details.',
    822 => 'HPS: The maximum number of retry transaction was breached.',
    823 => 'HPS: The merchants customer did not complete within the session timeout.',
    824 => 'HPS: Payment in flight. Awaiting customer ACS submission.',
    825 => 'HPS: Merchant not configured for full-hps',
    826 => 'HPS: The transaction has already been marked as final.',
    827 => 'HPS: Invalid capturemethod.',
    828 => 'HPS: Awaiting authorization.',
    829 => 'HPS: Invalid payment method for Full HPS txns.',
    845 => 'HPS: Paypal - Customer sent to the PayPal login page.',
    846 => 'HPS: Paypal - Waiting for customer to confirm payment.',
    847 => 'HPS: Paypal - Payment have confirmed funds available.',
    848 => 'HPS: Paypal - Invalid PayPal method.',
    849 => 'HPS: Paypal - Invalid PayPal payment action.',
    850 => 'HPS: Paypal - Invalid PayPal setup elements.',
    851 => 'HPS: Paypal - The Paypal txn was voided.',
    830 => 'Unable to establish connection to Westpac',
    831 => 'Invalid response received from Westpac',
    832 => 'Incorrect response received from Westpac',
    833 => 'Westpac: Communications Error',
    834 => 'Westpac: HTTP error in response',
    835 => 'Westpac server returned an error',
    836 => 'Westpac server rejected the transaction',
    837 => 'Duplicate merchant reference sent to Westpac',
    838 => 'Unexpected response from Westpac',
    839 => 'Error encountered at Westpac - transaction has not been processed',
    840 => 'Transaction could not be cancelled at Westpac',
    920 => 'Wirecard: An unknown error occurred while processing the transaction',
    921 => 'Wirecard: Unable to establish connection',
    922 => 'Wirecard: Unable to establish connection',
    923 => 'Wirecard: Invalid response received from Wirecard',
    924 => 'Wirecard: HTTP error on response',
    925 => 'Wirecard: Encryption failure at Wirecard',
    926 => 'Wirecard: Card issuer temporarily not reachable',
    927 => 'Wirecard: Processing temporarily not available',
    928 => 'Wirecard: Wirecard reported timeout while processing transaction',
    929 => 'Wirecard: Terminal not available',
    930 => 'Wirecard: Terminal not ready',
    931 => 'Wirecard: Amount larger than allowed',
    932 => 'Wirecard: Amount smaller than minimum amount',
    933 => 'Wirecard: Transaction processing not possible on terminal',
    934 => 'Connection to Wirecard timed out. Transaction in unknown state',
    935 => 'Wirecard: Airlines record may only be submitted as part of a fulfill transaction',
    936 => 'Wirecard: Unexpected response received from Wirecard',
    937 => 'Wirecard: Fulfill failed',
    991 => 'Tokenization: Invalid Token',
    992 => 'Tokenization: Unknown Token',
    993 => 'Tokenization: Not configured for service',
    994 => 'Tokenization: Expired Token',
    995 => 'Tokenization: Token generation is already taking place for this PAN',
    996 => 'Tokenization: Invalid shared secret',
    997 => 'Tokenization: Token generation resulted in a collision',
    1001 => 'Unable to establish connection.',
    1002 => 'The transaction was rejected by PayGate',
    1003 => 'An unknown error occurred while processing the transaction',
    1004 => 'Invalid response received from Paygate',
    1005 => 'Unable to establish connection',
    1006 => 'HTTP error on response',
    1007 => 'Partial fulfill not supported for PayGate',
    1031 => 'FDS:Unexpected response from FDS',
    1033 => 'FDS:Unable to establish connection',
    1034 => 'FDS:Unknown response received from FDS',
    1035 => 'FDS:Unknown Bank Failure',
    1036 => 'FDS:Merchant narrative is not support for FDS',
  );

  if (isset($error_messages[$status])) {
    return $error_messages[$status];
  }

  return FALSE;
}
